# Sampling

::: torchlinops.linops.Sampling
    options:
        inherited_members: false
        members:
            - __init__
            - from_mask
            - from_stacked_idx

::: torchlinops.linops.BreakpointLinop
    options:
        inherited_members: false
        members:
            - __init__
